#!/bin/bash

# Dumps the changelogentry table to a text file with a time
# stamp. Useful for calling by a cron job, for tracking activities in
# verinice. The following information are dumped:
#
# 1. Database-Id of the element
# 2. Timestamp
# 3. Object type
# 4. object title (if exists)
# 5. user
#
# @author Benjamin Weißenfels <bw@sernet.de>
# @version 0.1

#Path of the table dump
output_file="/tmp/changelogentry_`date +%Y-%m-%d-%H-%M-%S`.sql"

# Database user
database="verinicedb"

# verinice user
username="verinice"

# The password for the postgres user. This is not recommended, since
# some unix os allow non-root users to see enviromnent variables. It
# is also possible to use a password file or allow the verinice user
# in general connecting to the verinicedb from localhost. (this is
# done in /data/pg_data/pg_hba.conf). Then this variable can be unset.
export PGPASSWORD="verinice"

query="SELECT DISTINCT
	cnatreeelement.dbid as database_id,
	changelogentry.changetime as \"timestamp\",
	cnatreeelement.object_type,
	object_name,
	changelogentry.username
FROM (
	SELECT DISTINCT
		cnatreeelement.dbid as dbid,
		cnatreeelement.object_type,
		properties.propertytype,
		properties.propertyvalue as object_name
	FROM cnatreeelement
		JOIN entity ON cnatreeelement.entity_id=entity.dbid
		JOIN propertylist ON propertylist.typedlist_id=entity.dbid
		JOIN properties ON properties.properties_id=propertylist.dbid
	WHERE propertytype like '%_name') as object_names,
		cnatreeelement,
		changelogentry
WHERE
	changelogentry.elementid = cnatreeelement.dbid
AND
	changelogentry.elementid = object_names.dbid"

psql -d $database -U $username -w -c "${query}" >> $output_file

#remove the password from enviromnent
unset PGPASSWORD

exit
